pub mod prelude;

mod admin;
mod run;

use crate::{observe, prelude::*};
use prelude::*;

/// Web application for managing lyrics and live displays
#[derive(Parser)]
#[command(version, about, long_about = None)]
#[command(propagate_version = true)]
pub struct App {
    #[command(subcommand)]
    command: Commands,

    #[arg(global = true, long, value_enum, default_value = "info,lyrs=trace")]
    log_env_filter: String,
}

#[derive(Subcommand)]
enum Commands {
    /// Run the web application server
    Run(run::Run),

    /// Perform administrator actions
    Admin(admin::Admin),
}

pub async fn run() -> AnyResult<()> {
    let cli = App::parse();
    observe::setup_logging(&cli.log_env_filter)?;
    match cli.command {
        Commands::Run(args) => Ok(args.run().await?),
        Commands::Admin(args) => Ok(args.run().await?),
    }
}
